AbstractAsyncDropdownFieldParser class abstract

Inheritance

Properties

baseURL → DataParser<String>
no setter
defaultValue → DataParser<DropdownOption?>
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
linkedComponentsForData → DataParser<List<String>>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validator → DataParser<ComponentValidator<DropdownOption>>
no setteroverride

Methods

componentData(JsonMap data) → AsyncDropdownComponentData
override
getValue(AsyncDropdownFieldFuture data) → Future<List<DropdownOption>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited