DynamicFormSettings<ResultType> class

Constructors

DynamicFormSettings({required ComponentType fieldType, required bool isMandatory, required bool readOnly, required bool enabled, required String componentId, required String label, required AutovalidateMode autoValidateMode})

Properties

autoValidateMode → AutovalidateMode
final
componentId → String
final
enabled → bool
final
fieldType → ComponentType
final
hashCode → int
The hash code for this object.
no setterinherited
isMandatory → bool
final
label → String
final
readOnly → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({ComponentType? fieldType, bool? isMandatory, bool? readOnly, bool? enabled, String? prompt, String? label, AutovalidateMode? autoValidateMode}) → DynamicFormSettings
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited