AsyncDropdownComponentData class

Inheritance

Constructors

AsyncDropdownComponentData({required AbstractAsyncDropdownFieldParser parser, required JsonMap data})

Properties

baseURL → String
final
defaultValue → DropdownOption?
finalinherited
getValue → Future<List<DropdownOption>> Function(AsyncDropdownFieldFuture data)
final
hashCode → int
The hash code for this object.
no setterinherited
linkedComponentsForData → List<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validator → ComponentValidator<DropdownOption>
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited