CheckboxOption class

Inheritance
Annotations

Constructors

CheckboxOption({required String id, required String label, required bool readOnly})
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
id → String
finalinherited
label → String
finalinherited
readOnly → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override