DateTimePickerComponentData class

Inheritance

Constructors

DateTimePickerComponentData({required AbstractDateTimePickerFieldParser parser, required JsonMap data})

Properties

dateFormat → String?
final
dateTimePickerType → DateTimePickerType
final
defaultValue → DateTime?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validator → ComponentValidator<DateTime>
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited