InputComponentData class

Inheritance

Constructors

InputComponentData({required AbstractInputFieldParser parser, required JsonMap data})

Properties

autoCorrect → bool
final
autoFocus → bool
final
defaultValue → String?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textInputType → TextInputType
final
validator → ComponentValidator<String>
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited