ComponentLinker class

Constructors

ComponentLinker({required String componentId, required bool clearDependentOnUpdate, required bool disabledUntilParentIsValid, required bool clearDependentOnInvalidData, required String? disabledError})

Properties

clearDependentOnInvalidData → bool
final
clearDependentOnUpdate → bool
final
componentId → String
final
disabledError → String?
final
disabledUntilParentIsValid → bool
final
hashCode → int
The hash code for this object.
no setterinherited
linkedComponent ↔ BaseFormComponent<dynamic, BaseComponentData>
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

linkComponent(BaseFormComponent<dynamic, BaseComponentData> component) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited